@@ -3,13 +3,11 @@ package Search::InvertedIndex::Update;
 # $RCSfile: Update.pm,v $ $Revision: 1.5 $ $Date: 1999/06/15 22:31:07 $ $Author: snowhare $
 
 use strict;
-use Carp;
 use Class::NamedParms;
-use Class::ParmList;
 use vars qw (@ISA $VERSION);
 
 @ISA     = qw (Class::NamedParms);
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 =head1 NAME
 
@@ -22,6 +20,10 @@ Search::InvertedIndex::Update - A container for a mass data update for a -group/
 Provides a container for the information to perform an update for a -group/-index
 tuple.
 
+=head1 CHANGES
+
+1.01 2002.05.24 - Cleaned up 'new' method to improve performance.
+
 =head2 Public API
 
 Inherits 'get','set','clear' and 'exists' methods from Class::NamedParms
@@ -34,7 +36,7 @@ Inherits 'get','set','clear' and 'exists' methods from Class::NamedParms
 
 =over 4
 
-=item C<new($parm_ref);>
+=item C<new({ -group =E<gt> $group, -index =E<gt> $index, -keys =E<gt> { ... ) [ -data => E<gt> $data ] });>
 
 Returns and optionally initializes a new Search::InvertedIndex::Update
 object.
@@ -75,39 +77,30 @@ sub new {
 	my $proto = shift;
     my $class = ref ($proto) || $proto;
 	my $self  = Class::NamedParms->new(qw(-group -index -keys -data));
-
 	bless $self,$class;
 
-   # Read any passed parms
-    my ($parm_ref) = {};
+    # Read any passed parms
+    my $parm_ref = {};
     if ($#_ == 0) {
-        $parm_ref  = shift; 
-    } elsif ($#_ > 0) { 
-        %$parm_ref = @_; 
+        $parm_ref  = shift;
+    } elsif ($#_ > 0) {
+        %$parm_ref = @_;
     }
-
-	my $parms = Class::ParmList->new({ -parms => $parm_ref,
-    	                         -legal => [qw(-keys -data)],
-    	                      -required => [qw(-group -index)],
-    	                      -defaults => { -data => undef, 
-							                 '-keys' => {},
-										  },
-                               });
-   	if (not defined $parms) {
-   	    my $error_message = Class::ParmList->error;
-   	    croak (__PACKAGE__ . "::new() - $error_message\n");
-	}
-
-	$self->set($parms->all_parms);
-
-	$self;
+    if (not exists $parm_ref->{-data}) {
+        $parm_ref->{-data} = undef;
+    }
+    if (not exists $parm_ref->{-keys}) {
+        $parm_ref->{-keys} = undef;
+    }
+    $self->set($parm_ref);
+	return $self;
 }
 
 ####################################################################
 
 =head1 COPYRIGHT
 
-Copyright 1999, Benjamin Franz (<URL:http://www.nihongo.org/snowhare/>) and 
+Copyright 1999, Benjamin Franz (<URL:http://www.nihongo.org/snowhare/>) and
 FreeRun Technologies, Inc. (<URL:http://www.freeruntech.com/>). All Rights Reserved.
 This software may be copied or redistributed under the same terms as Perl itelf.
 
@@ -119,6 +112,10 @@ Benjamin Franz
 
 Everything.
 
+=head1 VERSION
+
+1.01 2002.05.24 - Changed initialization to improve performance
+
 =cut
 
 1;
